@@ -10,38 +10,36 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.compute import compute_service
 from openstack.compute.v2 import metadata
 from openstack import resource
 from openstack import utils
 
 
-class Server(resource.Resource, metadata.MetadataMixin):
+class Server(resource.Resource, metadata.MetadataMixin, resource.TagMixin):
     resource_key = 'server'
     resources_key = 'servers'
     base_path = '/servers'
-    service = compute_service.ComputeService()
 
     # capabilities
     allow_create = True
-    allow_get = True
-    allow_update = True
+    allow_fetch = True
+    allow_commit = True
     allow_delete = True
     allow_list = True
 
     _query_mapping = resource.QueryParameters(
         "image", "flavor", "name",
-        "status", "host", "all_tenants",
+        "status", "host",
         "sort_key", "sort_dir",
         "reservation_id", "tags",
         "project_id",
-        tags_any="tags-any",
-        not_tags="not-tags",
-        not_tags_any="not-tags-any",
         is_deleted="deleted",
         ipv4_address="ip",
         ipv6_address="ip6",
-        changes_since="changes-since")
+        changes_since="changes-since",
+        all_projects="all_tenants",
+        **resource.TagMixin._tag_query_parameters
+    )
 
     #: A list of dictionaries holding links relevant to this server.
     links = resource.Body('links')
@@ -189,7 +187,7 @@ class Server(resource.Resource, metadata.MetadataMixin):
     def get_password(self, session):
         """Get the encrypted administrator password."""
         url = utils.urljoin(Server.base_path, self.id, 'os-server-password')
-        return session.get(url, endpoint_filter=self.service)
+        return session.get(url)
 
     def reboot(self, session, reboot_type):
         """Reboot server where reboot_type might be 'SOFT' or 'HARD'."""
@@ -363,7 +361,8 @@ class Server(resource.Resource, metadata.MetadataMixin):
         resp = self._action(session, body)
         return resp.json()
 
-    def live_migrate(self, session, host, force, block_migration):
+    def live_migrate(self, session, host, force, block_migration,
+                     disk_over_commit=False):
         if utils.supports_microversion(session, '2.30'):
             return self._live_migrate_30(
                 session, host,
@@ -378,7 +377,8 @@ class Server(resource.Resource, metadata.MetadataMixin):
             return self._live_migrate(
                 session, host,
                 force=force,
-                block_migration=block_migration)
+                block_migration=block_migration,
+                disk_over_commit=disk_over_commit)
 
     def _live_migrate_30(self, session, host, force, block_migration):
         microversion = '2.30'
@@ -412,19 +412,18 @@ class Server(resource.Resource, metadata.MetadataMixin):
         self._action(
             session, {'os-migrateLive': body}, microversion=microversion)
 
-    def _live_migrate(self, session, host, force, block_migration):
+    def _live_migrate(self, session, host, force, block_migration,
+                      disk_over_commit):
         microversion = None
-        # disk_over_commit is not exposed because post 2.25 it has been
-        # removed and no SDK user is depending on it today.
         body = {
             'host': None,
-            'disk_over_commit': False,
         }
         if block_migration == 'auto':
             raise ValueError(
                 "Live migration on this cloud does not support 'auto' as"
                 " a parameter to block_migration, but only True and False.")
         body['block_migration'] = block_migration or False
+        body['disk_over_commit'] = disk_over_commit or False
         if host:
             body['host'] = host
             if not force:
@@ -444,9 +443,7 @@ class ServerDetail(Server):
 
     # capabilities
     allow_create = False
-    allow_get = False
-    allow_update = False
+    allow_fetch = False
+    allow_commit = False
     allow_delete = False
     allow_list = True
-
-    detail_for = Server
