@@ -15,9 +15,11 @@ from openstack.identity.v3 import credential as _credential
 from openstack.identity.v3 import domain as _domain
 from openstack.identity.v3 import endpoint as _endpoint
 from openstack.identity.v3 import group as _group
+from openstack.identity.v3 import limit as _limit
 from openstack.identity.v3 import policy as _policy
 from openstack.identity.v3 import project as _project
 from openstack.identity.v3 import region as _region
+from openstack.identity.v3 import registered_limit as _registered_limit
 from openstack.identity.v3 import role as _role
 from openstack.identity.v3 import role_assignment as _role_assignment
 from openstack.identity.v3 import role_domain_group_assignment \
@@ -94,7 +96,7 @@ class Proxy(proxy.Proxy):
     def credentials(self, **query):
         """Retrieve a generator of credentials
 
-        :param kwargs \*\*query: Optional query parameters to be sent to limit
+        :param kwargs query: Optional query parameters to be sent to limit
                                  the resources being returned.
 
         :returns: A generator of credentials instances.
@@ -172,7 +174,7 @@ class Proxy(proxy.Proxy):
     def domains(self, **query):
         """Retrieve a generator of domains
 
-        :param kwargs \*\*query: Optional query parameters to be sent to limit
+        :param kwargs query: Optional query parameters to be sent to limit
                                  the resources being returned.
 
         :returns: A generator of domain instances.
@@ -252,7 +254,7 @@ class Proxy(proxy.Proxy):
     def endpoints(self, **query):
         """Retrieve a generator of endpoints
 
-        :param kwargs \*\*query: Optional query parameters to be sent to limit
+        :param kwargs query: Optional query parameters to be sent to limit
                                  the resources being returned.
 
         :returns: A generator of endpoint instances.
@@ -332,7 +334,7 @@ class Proxy(proxy.Proxy):
     def groups(self, **query):
         """Retrieve a generator of groups
 
-        :param kwargs \*\*query: Optional query parameters to be sent to limit
+        :param kwargs query: Optional query parameters to be sent to limit
                                  the resources being returned.
 
         :returns: A generator of group instances.
@@ -410,7 +412,7 @@ class Proxy(proxy.Proxy):
     def policies(self, **query):
         """Retrieve a generator of policies
 
-        :param kwargs \*\*query: Optional query parameters to be sent to limit
+        :param kwargs query: Optional query parameters to be sent to limit
                                  the resources being returned.
 
         :returns: A generator of policy instances.
@@ -488,7 +490,7 @@ class Proxy(proxy.Proxy):
     def projects(self, **query):
         """Retrieve a generator of projects
 
-        :param kwargs \*\*query: Optional query parameters to be sent to limit
+        :param kwargs query: Optional query parameters to be sent to limit
                                  the resources being returned.
 
         :returns: A generator of project instances.
@@ -503,7 +505,7 @@ class Proxy(proxy.Proxy):
 
         :param user: Either the user id or an instance of
                      :class:`~openstack.identity.v3.user.User`
-        :param kwargs \*\*query: Optional query parameters to be sent to limit
+        :param kwargs query: Optional query parameters to be sent to limit
                                  the resources being returned.
 
         :returns: A generator of project instances.
@@ -582,7 +584,7 @@ class Proxy(proxy.Proxy):
     def services(self, **query):
         """Retrieve a generator of services
 
-        :param kwargs \*\*query: Optional query parameters to be sent to limit
+        :param kwargs query: Optional query parameters to be sent to limit
                                  the resources being returned.
 
         :returns: A generator of service instances.
@@ -660,7 +662,7 @@ class Proxy(proxy.Proxy):
     def users(self, **query):
         """Retrieve a generator of users
 
-        :param kwargs \*\*query: Optional query parameters to be sent to limit
+        :param kwargs query: Optional query parameters to be sent to limit
                                  the resources being returned.
 
         :returns: A generator of user instances.
@@ -738,7 +740,7 @@ class Proxy(proxy.Proxy):
     def trusts(self, **query):
         """Retrieve a generator of trusts
 
-        :param kwargs \*\*query: Optional query parameters to be sent to limit
+        :param kwargs query: Optional query parameters to be sent to limit
                                  the resources being returned.
 
         :returns: A generator of trust instances.
@@ -803,7 +805,7 @@ class Proxy(proxy.Proxy):
     def regions(self, **query):
         """Retrieve a generator of regions
 
-        :param kwargs \*\*query: Optional query parameters to be sent to limit
+        :param kwargs query: Optional query parameters to be sent to limit
                                  the regions being returned.
 
         :returns: A generator of region instances.
@@ -881,7 +883,7 @@ class Proxy(proxy.Proxy):
     def roles(self, **query):
         """Retrieve a generator of roles
 
-        :param kwargs \*\*query: Optional query parameters to be sent to limit
+        :param kwargs query: Optional query parameters to be sent to limit
                                  the resources being returned. The options
                                  are: domain_id, name.
         :return: A generator of role instances.
@@ -962,7 +964,7 @@ class Proxy(proxy.Proxy):
     def role_assignments(self, **query):
         """Retrieve a generator of role assignments
 
-        :param kwargs \*\*query: Optional query parameters to be sent to limit
+        :param kwargs query: Optional query parameters to be sent to limit
                                  the resources being returned. The options
                                  are: group_id, role_id, scope_domain_id,
                                  scope_project_id, user_id, include_names,
@@ -972,3 +974,158 @@ class Proxy(proxy.Proxy):
         """
         return self._list(_role_assignment.RoleAssignment,
                           paginated=False, **query)
+
+    def registered_limits(self, **query):
+        """Retrieve a generator of registered_limits
+
+        :param kwargs query: Optional query parameters to be sent to limit
+            the registered_limits being returned.
+
+        :returns: A generator of registered_limits instances.
+        :rtype: :class:
+            `~openstack.identity.v3.registered_limit.RegisteredLimit`
+        """
+        return self._list(_registered_limit.RegisteredLimit, paginated=False,
+                          **query)
+
+    def get_registered_limit(self, registered_limit):
+        """Get a single registered_limit
+
+        :param registered_limit: The value can be the ID of a registered_limit
+            or a :class:
+            `~openstack.identity.v3.registered_limit.RegisteredLimit` instance.
+
+        :returns: One :class:
+                  `~openstack.identity.v3.registered_limit.RegisteredLimit`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+                 when no resource can be found.
+        """
+        return self._get(_registered_limit.RegisteredLimit, registered_limit)
+
+    def create_registered_limit(self, **attrs):
+        """Create a new registered_limit from attributes
+
+        :param dict attrs: Keyword arguments which will be used to create
+            a :class:`~openstack.identity.v3.registered_limit.RegisteredLimit`,
+            comprised of the properties on the RegisteredLimit class.
+
+        :returns: The results of registered_limit creation.
+        :rtype: :class:
+            `~openstack.identity.v3.registered_limit.RegisteredLimit`
+        """
+        return self._create(_registered_limit.RegisteredLimit, **attrs)
+
+    def update_registered_limit(self, registered_limit, **attrs):
+        """Update a registered_limit
+
+        :param registered_limit: Either the ID of a registered_limit. or a
+            :class:`~openstack.identity.v3.registered_limit.RegisteredLimit`
+            instance.
+        :param dict kwargs: The attributes to update on the registered_limit
+            represented by ``value``.
+
+        :returns: The updated registered_limit.
+        :rtype: :class:
+            `~openstack.identity.v3.registered_limit.RegisteredLimit`
+        """
+        return self._update(_registered_limit.RegisteredLimit,
+                            registered_limit, **attrs)
+
+    def delete_registered_limit(self, registered_limit, ignore_missing=True):
+        """Delete a registered_limit
+
+        :param registered_limit: The value can be either the ID of a
+            registered_limit or a
+            :class:`~openstack.identity.v3.registered_limit.RegisteredLimit`
+            instance.
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be raised when
+            the registered_limit does not exist. When set to ``True``, no
+            exception will be thrown when attempting to delete a nonexistent
+            registered_limit.
+
+        :returns: ``None``
+        """
+        self._delete(_registered_limit.RegisteredLimit, registered_limit,
+                     ignore_missing=ignore_missing)
+
+    def limits(self, **query):
+        """Retrieve a generator of limits
+
+        :param kwargs query: Optional query parameters to be sent to limit
+            the limits being returned.
+
+        :returns: A generator of limits instances.
+        :rtype: :class:`~openstack.identity.v3.limit.Limit`
+        """
+        return self._list(_limit.Limit, paginated=False,
+                          **query)
+
+    def get_limit(self, limit):
+        """Get a single limit
+
+        :param limit: The value can be the ID of a limit
+            or a :class:`~openstack.identity.v3.limit.Limit` instance.
+
+        :returns: One :class:
+                  `~openstack.identity.v3.limit.Limit`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound` when no
+            resource can be found.
+        """
+        return self._get(_limit.Limit, limit)
+
+    def create_limit(self, **attrs):
+        """Create a new limit from attributes
+
+        :param dict attrs: Keyword arguments which will be used to create
+            a :class:`~openstack.identity.v3.limit.Limit`, comprised of the
+            properties on the Limit class.
+
+        :returns: The results of limit creation.
+        :rtype: :class:`~openstack.identity.v3.limit.Limit`
+        """
+        return self._create(_limit.Limit, **attrs)
+
+    def update_limit(self, limit, **attrs):
+        """Update a limit
+
+        :param limit: Either the ID of a limit. or a
+            :class:`~openstack.identity.v3.limit.Limit` instance.
+        :param dict kwargs: The attributes to update on the limit represented
+            by ``value``.
+
+        :returns: The updated limit.
+        :rtype: :class:`~openstack.identity.v3.limit.Limit`
+        """
+        return self._update(_limit.Limit,
+                            limit, **attrs)
+
+    def delete_limit(self, limit, ignore_missing=True):
+        """Delete a limit
+
+        :param limit: The value can be either the ID of a limit or a
+            :class:`~openstack.identity.v3.limit.Limit` instance.
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be raised when
+            the limit does not exist. When set to ``True``, no exception will
+            be thrown when attempting to delete a nonexistent limit.
+
+        :returns: ``None``
+        """
+        self._delete(limit.Limit, limit,
+                     ignore_missing=ignore_missing)
+
+    def assign_project_role_to_user(self, project, user, role):
+        """Assign role to user on a project
+
+        :param project: Either the ID of a project or a
+                      :class:`~openstack.identity.v3.project.Project`
+                      instance.
+        :param user: Either the ID of a user or a
+                     :class:`~openstack.identity.v3.user.User` instance.
+        :param role: Either the ID of a role or a
+                     :class:`~openstack.identity.v3.role.Role` instance.
+        :return: ``None``
+        """
+        project = self._get_resource(_project.Project, project)
+        project.assign_role_to_user(self, user, role)
