@@ -12,29 +12,26 @@
 
 import hashlib
 
-import jsonpatch
-
 from openstack import _log
 from openstack import exceptions
-from openstack.image import image_service
 from openstack import resource
 from openstack import utils
 
 _logger = _log.setup_logging('openstack')
 
 
-class Image(resource.Resource):
+class Image(resource.Resource, resource.TagMixin):
     resources_key = 'images'
     base_path = '/images'
-    service = image_service.ImageService()
 
     # capabilities
     allow_create = True
-    allow_get = True
-    allow_update = True
+    allow_fetch = True
+    allow_commit = True
     allow_delete = True
     allow_list = True
-    update_method = 'PATCH'
+    commit_method = 'PATCH'
+    commit_jsonpatch = True
 
     _query_mapping = resource.QueryParameters(
         "name", "visibility",
@@ -83,8 +80,11 @@ class Image(resource.Resource):
     name = resource.Body('name')
     #: The ID of the owner, or project, of the image.
     owner_id = resource.Body('owner')
+    # TODO(mordred) This is not how this works in v2. I mean, it's how it
+    # should work, but it's not. We need to fix properties. They work right
+    # in shade, so we can draw some logic from there.
     #: Properties, if any, that are associated with the image.
-    properties = resource.Body('properties', type=dict)
+    properties = resource.Body('properties')
     #: The size of the image data, in bytes.
     size = resource.Body('size', type=int)
     #: When present, Glance will attempt to store the disk image data in the
@@ -113,12 +113,6 @@ class Image(resource.Resource):
     #: when you set the show_image_direct_url option to true in the
     #: Image service's configuration file.
     direct_url = resource.Body('direct_url')
-    #: An image property.
-    path = resource.Body('path')
-    #: Value of image property used in add or replace operations expressed
-    #: in JSON notation. For example, you must enclose strings in quotation
-    #: marks, and you do not enclose numeric values in quotation marks.
-    value = resource.Body('value')
     #: The URL to access the image file kept in external store.
     url = resource.Body('url')
     #: The location metadata.
@@ -211,6 +205,12 @@ class Image(resource.Resource):
     has_auto_disk_config = resource.Body('auto_disk_config', type=bool)
     #: The operating system installed on the image.
     os_type = resource.Body('os_type')
+    #: The operating system admin username.
+    os_admin_user = resource.Body('os_admin_user')
+    #: If true, QEMU guest agent will be exposed to the instance.
+    hw_qemu_guest_agent = resource.Body('hw_qemu_guest_agent', type=bool)
+    #: If true, require quiesce on snapshot via QEMU guest agent.
+    os_require_quiesce = resource.Body('os_require_quiesce', type=bool)
 
     def _action(self, session, action):
         """Call an action on an image ID."""
@@ -232,16 +232,6 @@ class Image(resource.Resource):
         """
         self._action(session, "reactivate")
 
-    def add_tag(self, session, tag):
-        """Add a tag to an image"""
-        url = utils.urljoin(self.base_path, self.id, 'tags', tag)
-        session.put(url,)
-
-    def remove_tag(self, session, tag):
-        """Remove a tag from an image"""
-        url = utils.urljoin(self.base_path, self.id, 'tags', tag)
-        session.delete(url,)
-
     def upload(self, session):
         """Upload data into an existing image"""
         url = utils.urljoin(self.base_path, self.id, 'file')
@@ -265,7 +255,7 @@ class Image(resource.Resource):
             # If we don't receive the Content-MD5 header with the download,
             # make an additional call to get the image details and look at
             # the checksum attribute.
-            details = self.get(session)
+            details = self.fetch(session)
             checksum = details.checksum
 
         # if we are returning the repsonse object, ensure that it
@@ -287,21 +277,16 @@ class Image(resource.Resource):
 
         return resp.content
 
-    def update(self, session, **attrs):
-        url = utils.urljoin(self.base_path, self.id)
-        headers = {
-            'Content-Type': 'application/openstack-images-v2.1-json-patch',
-            'Accept': ''
-        }
-        original = self.to_dict()
+    def _prepare_request(self, requires_id=None, prepend_key=False,
+                         patch=False):
+        request = super(Image, self)._prepare_request(requires_id=requires_id,
+                                                      prepend_key=prepend_key,
+                                                      patch=patch)
+        if patch:
+            headers = {
+                'Content-Type': 'application/openstack-images-v2.1-json-patch',
+                'Accept': ''
+            }
+            request.headers.update(headers)
 
-        # Update values from **attrs so they can be passed to jsonpatch
-        new = self.to_dict()
-        new.update(**attrs)
-
-        patch_string = jsonpatch.make_patch(original, new).to_string()
-        resp = session.patch(url,
-                             data=patch_string,
-                             headers=headers)
-        self._translate_response(resp, has_body=True)
-        return self
+        return request
