@@ -10,7 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.network import network_service
 from openstack import resource
 
 
@@ -18,11 +17,10 @@ class Quota(resource.Resource):
     resource_key = 'quota'
     resources_key = 'quotas'
     base_path = '/quotas'
-    service = network_service.NetworkService()
 
     # capabilities
-    allow_get = True
-    allow_update = True
+    allow_fetch = True
+    allow_commit = True
     allow_delete = True
     allow_list = True
 
@@ -75,7 +73,7 @@ class QuotaDefault(Quota):
 
     # capabilities
     allow_retrieve = True
-    allow_update = False
+    allow_commit = False
     allow_delete = False
     allow_list = False
 
@@ -89,7 +87,7 @@ class QuotaDetails(Quota):
 
     # capabilities
     allow_retrieve = True
-    allow_update = False
+    allow_commit = False
     allow_delete = False
     allow_list = False
 
