@@ -10,31 +10,33 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.orchestration import orchestration_service
-from openstack import resource2 as resource
+from openstack import resource
 
 
 class StackFiles(resource.Resource):
 
-    service = orchestration_service.OrchestrationService()
     base_path = "/stacks/%(stack_name)s/%(stack_id)s/files"
 
     # capabilities
     allow_create = False
     allow_list = False
-    allow_get = True
+    allow_fetch = True
     allow_delete = False
-    allow_update = False
+    allow_commit = False
 
     # Properties
     #: Name of the stack where the template is referenced.
-    stack_name = resource.URI('stack_name')
+    name = resource.URI('stack_name')
+    # Backwards compat
+    stack_name = name
     #: ID of the stack where the template is referenced.
-    stack_id = resource.URI('stack_id')
+    id = resource.URI('stack_id')
+    # Backwards compat
+    stack_id = id
 
-    def get(self, session):
+    def fetch(self, session):
         # The stack files response contains a map of filenames and file
         # contents.
         request = self._prepare_request(requires_id=False)
-        resp = session.get(request.uri, endpoint_filter=self.service)
+        resp = session.get(request.url)
         return resp.json()
