@@ -10,7 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import uuid
 
 from openstack.network.v2 import qos_policy as _qos_policy
 from openstack.tests.functional import base
@@ -19,30 +18,29 @@ from openstack.tests.functional import base
 class TestQoSPolicy(base.BaseFunctionalTest):
 
     QOS_POLICY_ID = None
-    QOS_POLICY_NAME = uuid.uuid4().hex
-    QOS_POLICY_NAME_UPDATED = uuid.uuid4().hex
     IS_SHARED = False
     IS_DEFAULT = False
     RULES = []
     QOS_POLICY_DESCRIPTION = "QoS policy description"
 
-    @classmethod
-    def setUpClass(cls):
-        super(TestQoSPolicy, cls).setUpClass()
-        qos = cls.conn.network.create_qos_policy(
-            description=cls.QOS_POLICY_DESCRIPTION,
-            name=cls.QOS_POLICY_NAME,
-            shared=cls.IS_SHARED,
-            is_default=cls.IS_DEFAULT,
+    def setUp(self):
+        super(TestQoSPolicy, self).setUp()
+        self.QOS_POLICY_NAME = self.getUniqueString()
+        self.QOS_POLICY_NAME_UPDATED = self.getUniqueString()
+        qos = self.conn.network.create_qos_policy(
+            description=self.QOS_POLICY_DESCRIPTION,
+            name=self.QOS_POLICY_NAME,
+            shared=self.IS_SHARED,
+            is_default=self.IS_DEFAULT,
         )
         assert isinstance(qos, _qos_policy.QoSPolicy)
-        cls.assertIs(cls.QOS_POLICY_NAME, qos.name)
-        cls.QOS_POLICY_ID = qos.id
+        self.assertEqual(self.QOS_POLICY_NAME, qos.name)
+        self.QOS_POLICY_ID = qos.id
 
-    @classmethod
-    def tearDownClass(cls):
-        sot = cls.conn.network.delete_qos_policy(cls.QOS_POLICY_ID)
-        cls.assertIs(None, sot)
+    def tearDown(self):
+        sot = self.conn.network.delete_qos_policy(self.QOS_POLICY_ID)
+        self.assertIsNone(sot)
+        super(TestQoSPolicy, self).tearDown()
 
     def test_find(self):
         sot = self.conn.network.find_qos_policy(self.QOS_POLICY_NAME)
@@ -65,3 +63,15 @@ class TestQoSPolicy(base.BaseFunctionalTest):
             self.QOS_POLICY_ID,
             name=self.QOS_POLICY_NAME_UPDATED)
         self.assertEqual(self.QOS_POLICY_NAME_UPDATED, sot.name)
+
+    def test_set_tags(self):
+        sot = self.conn.network.get_qos_policy(self.QOS_POLICY_ID)
+        self.assertEqual([], sot.tags)
+
+        self.conn.network.set_tags(sot, ['blue'])
+        sot = self.conn.network.get_qos_policy(self.QOS_POLICY_ID)
+        self.assertEqual(['blue'], sot.tags)
+
+        self.conn.network.set_tags(sot, [])
+        sot = self.conn.network.get_qos_policy(self.QOS_POLICY_ID)
+        self.assertEqual([], sot.tags)
