@@ -21,7 +21,7 @@ import uuid
 
 import mock
 
-import openstack.cloud
+from openstack.cloud import openstackcloud
 from openstack.cloud import exc
 from openstack.cloud import meta
 from openstack.tests import fakes
@@ -325,7 +325,7 @@ class TestCreateServer(base.TestCase):
 
         self.assert_calls()
 
-    @mock.patch.object(openstack.cloud.OpenStackCloud, "wait_for_server")
+    @mock.patch.object(openstackcloud._OpenStackCloudMixin, "wait_for_server")
     def test_create_server_with_admin_pass_wait(self, mock_wait):
         """
         Test that a server with an admin_pass passed returns the password
@@ -411,8 +411,9 @@ class TestCreateServer(base.TestCase):
 
         self.assert_calls()
 
-    @mock.patch.object(openstack.cloud.OpenStackCloud, "get_active_server")
-    @mock.patch.object(openstack.cloud.OpenStackCloud, "get_server")
+    @mock.patch.object(
+        openstackcloud._OpenStackCloudMixin, "get_active_server")
+    @mock.patch.object(openstackcloud._OpenStackCloudMixin, "get_server")
     def test_wait_for_server(self, mock_get_server, mock_get_active_server):
         """
         Test that waiting for a server returns the server instance when
@@ -446,7 +447,7 @@ class TestCreateServer(base.TestCase):
 
         self.assertEqual('ACTIVE', server['status'])
 
-    @mock.patch.object(openstack.cloud.OpenStackCloud, 'wait_for_server')
+    @mock.patch.object(openstackcloud._OpenStackCloudMixin, 'wait_for_server')
     def test_create_server_wait(self, mock_wait):
         """
         Test that create_server with a wait actually does the wait.
@@ -483,7 +484,8 @@ class TestCreateServer(base.TestCase):
         )
         self.assert_calls()
 
-    @mock.patch.object(openstack.cloud.OpenStackCloud, 'add_ips_to_server')
+    @mock.patch.object(
+        openstackcloud._OpenStackCloudMixin, 'add_ips_to_server')
     def test_create_server_no_addresses(
             self, mock_add_ips_to_server):
         """
@@ -630,6 +632,152 @@ class TestCreateServer(base.TestCase):
             network='network-name', nics=[])
         self.assert_calls()
 
+    def test_create_server_network_fixed_ip(self):
+        """
+        Verify that if 'fixed_ip' is supplied in nics, we pass it to networks
+        appropriately.
+        """
+        network = {
+            'id': 'network-id',
+            'name': 'network-name'
+        }
+        fixed_ip = '10.0.0.1'
+        build_server = fakes.make_fake_server('1234', '', 'BUILD')
+        self.register_uris([
+            dict(method='POST',
+                 uri=self.get_mock_url(
+                     'compute', 'public', append=['servers']),
+                 json={'server': build_server},
+                 validate=dict(
+                     json={'server': {
+                         u'flavorRef': u'flavor-id',
+                         u'imageRef': u'image-id',
+                         u'max_count': 1,
+                         u'min_count': 1,
+                         u'networks': [{'fixed_ip': fixed_ip}],
+                         u'name': u'server-name'}})),
+            dict(method='GET',
+                 uri=self.get_mock_url(
+                     'compute', 'public', append=['servers', '1234']),
+                 json={'server': build_server}),
+            dict(method='GET',
+                 uri=self.get_mock_url(
+                     'network', 'public', append=['v2.0', 'networks.json']),
+                 json={'networks': [network]}),
+            dict(method='GET',
+                 uri=self.get_mock_url(
+                     'network', 'public', append=['v2.0', 'subnets.json']),
+                 json={'subnets': []}),
+        ])
+        self.cloud.create_server(
+            'server-name', dict(id='image-id'), dict(id='flavor-id'),
+            nics=[{'fixed_ip': fixed_ip}])
+        self.assert_calls()
+
+    def test_create_server_network_v4_fixed_ip(self):
+        """
+        Verify that if 'v4-fixed-ip' is supplied in nics, we pass it to
+        networks appropriately.
+        """
+        network = {
+            'id': 'network-id',
+            'name': 'network-name'
+        }
+        fixed_ip = '10.0.0.1'
+        build_server = fakes.make_fake_server('1234', '', 'BUILD')
+        self.register_uris([
+            dict(method='POST',
+                 uri=self.get_mock_url(
+                     'compute', 'public', append=['servers']),
+                 json={'server': build_server},
+                 validate=dict(
+                     json={'server': {
+                         u'flavorRef': u'flavor-id',
+                         u'imageRef': u'image-id',
+                         u'max_count': 1,
+                         u'min_count': 1,
+                         u'networks': [{'fixed_ip': fixed_ip}],
+                         u'name': u'server-name'}})),
+            dict(method='GET',
+                 uri=self.get_mock_url(
+                     'compute', 'public', append=['servers', '1234']),
+                 json={'server': build_server}),
+            dict(method='GET',
+                 uri=self.get_mock_url(
+                     'network', 'public', append=['v2.0', 'networks.json']),
+                 json={'networks': [network]}),
+            dict(method='GET',
+                 uri=self.get_mock_url(
+                     'network', 'public', append=['v2.0', 'subnets.json']),
+                 json={'subnets': []}),
+        ])
+        self.cloud.create_server(
+            'server-name', dict(id='image-id'), dict(id='flavor-id'),
+            nics=[{'fixed_ip': fixed_ip}])
+        self.assert_calls()
+
+    def test_create_server_network_v6_fixed_ip(self):
+        """
+        Verify that if 'v6-fixed-ip' is supplied in nics, we pass it to
+        networks appropriately.
+        """
+        network = {
+            'id': 'network-id',
+            'name': 'network-name'
+        }
+        # Note - it doesn't actually have to be a v6 address - it's just
+        # an alias.
+        fixed_ip = 'fe80::28da:5fff:fe57:13ed'
+        build_server = fakes.make_fake_server('1234', '', 'BUILD')
+        self.register_uris([
+            dict(method='POST',
+                 uri=self.get_mock_url(
+                     'compute', 'public', append=['servers']),
+                 json={'server': build_server},
+                 validate=dict(
+                     json={'server': {
+                         u'flavorRef': u'flavor-id',
+                         u'imageRef': u'image-id',
+                         u'max_count': 1,
+                         u'min_count': 1,
+                         u'networks': [{'fixed_ip': fixed_ip}],
+                         u'name': u'server-name'}})),
+            dict(method='GET',
+                 uri=self.get_mock_url(
+                     'compute', 'public', append=['servers', '1234']),
+                 json={'server': build_server}),
+            dict(method='GET',
+                 uri=self.get_mock_url(
+                     'network', 'public', append=['v2.0', 'networks.json']),
+                 json={'networks': [network]}),
+            dict(method='GET',
+                 uri=self.get_mock_url(
+                     'network', 'public', append=['v2.0', 'subnets.json']),
+                 json={'subnets': []}),
+        ])
+        self.cloud.create_server(
+            'server-name', dict(id='image-id'), dict(id='flavor-id'),
+            nics=[{'fixed_ip': fixed_ip}])
+        self.assert_calls()
+
+    def test_create_server_network_fixed_ip_conflicts(self):
+        """
+        Verify that if 'fixed_ip' and 'v4-fixed-ip' are both supplied in nics,
+        we throw an exception.
+        """
+        # Note - it doesn't actually have to be a v6 address - it's just
+        # an alias.
+        self.use_nothing()
+        fixed_ip = '10.0.0.1'
+        self.assertRaises(
+            exc.OpenStackCloudException, self.cloud.create_server,
+            'server-name', dict(id='image-id'), dict(id='flavor-id'),
+            nics=[{
+                'fixed_ip': fixed_ip,
+                'v4-fixed-ip': fixed_ip
+            }])
+        self.assert_calls()
+
     def test_create_server_get_flavor_image(self):
         self.use_glance()
         image_id = str(uuid.uuid4())
