@@ -418,10 +418,17 @@ class TestComputeProxy(test_proxy_base.TestProxyBase):
                      method_args=["value", 1],
                      expected_kwargs={"length": 1})
 
-    def test_availability_zones(self):
-        self.verify_list_no_kwargs(self.proxy.availability_zones,
-                                   az.AvailabilityZone,
-                                   paginated=False)
+    def test_availability_zones_not_detailed(self):
+        self.verify_list(self.proxy.availability_zones,
+                         az.AvailabilityZone,
+                         paginated=False,
+                         method_kwargs={"details": False})
+
+    def test_availability_zones_detailed(self):
+        self.verify_list(self.proxy.availability_zones,
+                         az.AvailabilityZoneDetail,
+                         paginated=False,
+                         method_kwargs={"details": True})
 
     def test_get_all_server_metadata(self):
         self._verify2("openstack.compute.v2.server.Server.get_metadata",
@@ -475,10 +482,15 @@ class TestComputeProxy(test_proxy_base.TestProxyBase):
         self.verify_list(self.proxy.server_groups, server_group.ServerGroup,
                          paginated=False)
 
-    def test_hypervisors(self):
-        self.verify_list_no_kwargs(self.proxy.hypervisors,
-                                   hypervisor.Hypervisor,
-                                   paginated=False)
+    def test_hypervisors_not_detailed(self):
+        self.verify_list(self.proxy.hypervisors, hypervisor.Hypervisor,
+                         paginated=False,
+                         method_kwargs={"details": False})
+
+    def test_hypervisors_detailed(self):
+        self.verify_list(self.proxy.hypervisors, hypervisor.HypervisorDetail,
+                         paginated=False,
+                         method_kwargs={"details": True})
 
     def test_find_hypervisor(self):
         self.verify_find(self.proxy.find_hypervisor,
@@ -514,5 +526,6 @@ class TestComputeProxy(test_proxy_base.TestProxyBase):
     def test_live_migrate_server(self):
         self._verify('openstack.compute.v2.server.Server.live_migrate',
                      self.proxy.live_migrate_server,
-                     method_args=["value", "host1", "force"],
-                     expected_args=["host1", "force"])
+                     method_args=["value", "host1", False],
+                     expected_args=["host1"],
+                     expected_kwargs={'force': False, 'block_migration': None})
