@@ -49,11 +49,10 @@ class TestListener(base.TestCase):
         test_listener = listener.Listener()
         self.assertEqual('listener', test_listener.resource_key)
         self.assertEqual('listeners', test_listener.resources_key)
-        self.assertEqual('/v2.0/lbaas/listeners', test_listener.base_path)
-        self.assertEqual('load-balancer', test_listener.service.service_type)
+        self.assertEqual('/lbaas/listeners', test_listener.base_path)
         self.assertTrue(test_listener.allow_create)
-        self.assertTrue(test_listener.allow_get)
-        self.assertTrue(test_listener.allow_update)
+        self.assertTrue(test_listener.allow_fetch)
+        self.assertTrue(test_listener.allow_commit)
         self.assertTrue(test_listener.allow_delete)
         self.assertTrue(test_listener.allow_list)
 
