@@ -10,7 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import deprecation
 import mock
 import uuid
 
@@ -21,6 +20,9 @@ from openstack.network.v2 import agent
 from openstack.network.v2 import auto_allocated_topology
 from openstack.network.v2 import availability_zone
 from openstack.network.v2 import extension
+from openstack.network.v2 import firewall_group
+from openstack.network.v2 import firewall_policy
+from openstack.network.v2 import firewall_rule
 from openstack.network.v2 import flavor
 from openstack.network.v2 import floating_ip
 from openstack.network.v2 import health_monitor
@@ -873,6 +875,93 @@ class TestNetworkProxy(test_proxy_base.TestProxyBase):
             expected_kwargs={'agent_id': AGENT_ID},
         )
 
+    def test_firewall_group_create_attrs(self):
+        self.verify_create(self.proxy.create_firewall_group,
+                           firewall_group.FirewallGroup)
+
+    def test_firewall_group_delete(self):
+        self.verify_delete(self.proxy.delete_firewall_group,
+                           firewall_group.FirewallGroup, False)
+
+    def test_firewall_group_delete_ignore(self):
+        self.verify_delete(self.proxy.delete_firewall_group,
+                           firewall_group.FirewallGroup, True)
+
+    def test_firewall_group_find(self):
+        self.verify_find(self.proxy.find_firewall_group,
+                         firewall_group.FirewallGroup)
+
+    def test_firewall_group_get(self):
+        self.verify_get(self.proxy.get_firewall_group,
+                        firewall_group.FirewallGroup)
+
+    def test_firewall_groups(self):
+        self.verify_list(self.proxy.firewall_groups,
+                         firewall_group.FirewallGroup,
+                         paginated=False)
+
+    def test_firewall_group_update(self):
+        self.verify_update(self.proxy.update_firewall_group,
+                           firewall_group.FirewallGroup)
+
+    def test_firewall_policy_create_attrs(self):
+        self.verify_create(self.proxy.create_firewall_policy,
+                           firewall_policy.FirewallPolicy)
+
+    def test_firewall_policy_delete(self):
+        self.verify_delete(self.proxy.delete_firewall_policy,
+                           firewall_policy.FirewallPolicy, False)
+
+    def test_firewall_policy_delete_ignore(self):
+        self.verify_delete(self.proxy.delete_firewall_policy,
+                           firewall_policy.FirewallPolicy, True)
+
+    def test_firewall_policy_find(self):
+        self.verify_find(self.proxy.find_firewall_policy,
+                         firewall_policy.FirewallPolicy)
+
+    def test_firewall_policy_get(self):
+        self.verify_get(self.proxy.get_firewall_policy,
+                        firewall_policy.FirewallPolicy)
+
+    def test_firewall_policies(self):
+        self.verify_list(self.proxy.firewall_policies,
+                         firewall_policy.FirewallPolicy,
+                         paginated=False)
+
+    def test_firewall_policy_update(self):
+        self.verify_update(self.proxy.update_firewall_policy,
+                           firewall_policy.FirewallPolicy)
+
+    def test_firewall_rule_create_attrs(self):
+        self.verify_create(self.proxy.create_firewall_rule,
+                           firewall_rule.FirewallRule)
+
+    def test_firewall_rule_delete(self):
+        self.verify_delete(self.proxy.delete_firewall_rule,
+                           firewall_rule.FirewallRule, False)
+
+    def test_firewall_rule_delete_ignore(self):
+        self.verify_delete(self.proxy.delete_firewall_rule,
+                           firewall_rule.FirewallRule, True)
+
+    def test_firewall_rule_find(self):
+        self.verify_find(self.proxy.find_firewall_rule,
+                         firewall_rule.FirewallRule)
+
+    def test_firewall_rule_get(self):
+        self.verify_get(self.proxy.get_firewall_rule,
+                        firewall_rule.FirewallRule)
+
+    def test_firewall_rules(self):
+        self.verify_list(self.proxy.firewall_rules,
+                         firewall_rule.FirewallRule,
+                         paginated=False)
+
+    def test_firewall_rule_update(self):
+        self.verify_update(self.proxy.update_firewall_rule,
+                           firewall_rule.FirewallRule)
+
     def test_security_group_create_attrs(self):
         self.verify_create(self.proxy.create_security_group,
                            security_group.SecurityGroup)
@@ -902,49 +991,6 @@ class TestNetworkProxy(test_proxy_base.TestProxyBase):
         self.verify_update(self.proxy.update_security_group,
                            security_group.SecurityGroup)
 
-    @deprecation.fail_if_not_removed
-    def test_security_group_open_port(self):
-        mock_class = 'openstack.network.v2._proxy.Proxy'
-        mock_method = mock_class + '.create_security_group_rule'
-        expected_result = 'result'
-        sgid = 1
-        port = 2
-        with mock.patch(mock_method) as mocked:
-            mocked.return_value = expected_result
-            actual = self.proxy.security_group_open_port(sgid, port)
-            self.assertEqual(expected_result, actual)
-            expected_args = {
-                'direction': 'ingress',
-                'protocol': 'tcp',
-                'remote_ip_prefix': '0.0.0.0/0',
-                'port_range_max': port,
-                'security_group_id': sgid,
-                'port_range_min': port,
-                'ethertype': 'IPv4',
-            }
-            mocked.assert_called_with(**expected_args)
-
-    @deprecation.fail_if_not_removed
-    def test_security_group_allow_ping(self):
-        mock_class = 'openstack.network.v2._proxy.Proxy'
-        mock_method = mock_class + '.create_security_group_rule'
-        expected_result = 'result'
-        sgid = 1
-        with mock.patch(mock_method) as mocked:
-            mocked.return_value = expected_result
-            actual = self.proxy.security_group_allow_ping(sgid)
-            self.assertEqual(expected_result, actual)
-            expected_args = {
-                'direction': 'ingress',
-                'protocol': 'icmp',
-                'remote_ip_prefix': '0.0.0.0/0',
-                'port_range_max': None,
-                'security_group_id': sgid,
-                'port_range_min': None,
-                'ethertype': 'IPv4',
-            }
-            mocked.assert_called_with(**expected_args)
-
     def test_security_group_rule_create_attrs(self):
         self.verify_create(self.proxy.create_security_group_rule,
                            security_group_rule.SecurityGroupRule)
